@@ -6,7 +6,8 @@ import qualified Data.Yaml as Y
 
 main :: IO ()
 main = do
-  print $ (Y.decode "[1,2,3]" :: Maybe [Integer])
+  res <- Y.decodeThrow "[1,2,3]"
+  print (res :: [Integer])
 
 -- You can go one step further and decode into a custom type by implementing
 -- 'FromJSON' for that type. This is also appropriate where extra
